==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Истекло время аутентификации</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Диск занят, не могу отмонтировать сейчас</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation> Диск занят и не может быть извлечён сейчас</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Устройство занято, сейчас извлечь нельзя</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Устройство занято, сейчас удалить нельзя</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Объём</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Устройство не было безопасно удалено</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>В следующий раз нажмите &quot;Безопасное удаление&quot;, а затем отключите его</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Устройство занято, сейчас извлечь нельзя</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Устройство занято, сейчас удалить нельзя</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Не могу отключить устройство</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Диск смонтирован пользователем &quot;%1&quot;, вы не сможете его размонтировать.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Не удается найти подключенное устройство</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Диски</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Извлечь все</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Устройство было безопасно удалено</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Доступ закрыт</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>У вас нет разрешения на доступ к этой папке</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Сканирование устройства, остановить его?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.9.orig.tar.xz: dde-file-manager-5.6.9/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Истекло время аутентификации</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Диск занят, не могу отмонтировать сейчас</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation> Диск занят и не может быть извлечён сейчас</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Устройство занято и не может быть извлечено сейчас</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Устройство занято, сейчас извлечь нельзя</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Объём</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Устройство не было безопасно извлечено</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>В следующий раз сначала нажмите &quot;Безопасное извлечение&quot;, а затем отключите устройство</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Невозможно отключить устройство</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Диск смонтирован пользователем &quot;%1&quot;, вы не сможете его размонтировать.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Не удается найти подключенное устройство</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Диски</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Извлечь все</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Устройство было безопасно извлечено</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Доступ запрещен</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>У вас нет права доступа к этой папке</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Сканирование устройства, остановить его?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Стоп</translation>
    </message>
</context>
</TS>
